build method
Builds the subtree. Observables read via ref.watch are subscribed to,
and a change to any of them rebuilds this widget only.
Implementation
@override
Widget build(BuildContext context, ReactiveBlockRefExt ref) => _builder(ref);
Builds the subtree. Observables read via ref.watch are subscribed to,
and a change to any of them rebuilds this widget only.
@override
Widget build(BuildContext context, ReactiveBlockRefExt ref) => _builder(ref);