build abstract method
Builds the subtree. Observables read via ref.watch are subscribed to,
and a change to any of them rebuilds this widget only.
Implementation
Widget build(BuildContext context, ReactiveBlockRefExt ref);
Builds the subtree. Observables read via ref.watch are subscribed to,
and a change to any of them rebuilds this widget only.
Widget build(BuildContext context, ReactiveBlockRefExt ref);