ReactiveBlockRefExt class abstract
- Inheritance
-
- Object
- ReactiveBlockRef
- ReactiveBlockRefExt
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disableUntilCompleted(
Future< void> action()) → Future<void> Function()? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
watch<
T> (ValueListenable< T> observable) → T -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited