watch<T> abstract method
Returns the current value of observable and subscribes the enclosing
reactive block to it.
Implementation
@override
T watch<T>(ValueListenable<T> observable);
Returns the current value of observable and subscribes the enclosing
reactive block to it.
@override
T watch<T>(ValueListenable<T> observable);