toString method
Always throws — see Rx.toString.
Implementation
@override
String toString() =>
throw AssertionError("RxEvent is not supposed to use directly in interpolation, use RxEventListener");
Always throws — see Rx.toString.
@override
String toString() =>
throw AssertionError("RxEvent is not supposed to use directly in interpolation, use RxEventListener");