toString method
Always throws — see Rx.toString.
Implementation
@override
String toString() => throw AssertionError("RxList is not supposed to use directly in interpolation, use ref.watch()");
Always throws — see Rx.toString.
@override
String toString() => throw AssertionError("RxList is not supposed to use directly in interpolation, use ref.watch()");